============
Python Piwik
============

Generic django application and a wrapper class for calling Piwik API (http://piwik.org).

Django
======

Add piwik tracker in your template and show stats inside django admin site.

Documentation
=============

http://forge.2metz.fr/p/python-piwik/
